@@ -186,9 +186,10 @@ class notion_connector:
 # Retourne le champs title de la db
 ###################################
 	def getTitleProperties(self, db):
-		for i in db['properties'].items():
-			if i[1]['type'] == 'Title':
-				return i[0]
+		line = db[0]['properties']
+		for i in line.items():
+			if i[1]['properties']['type'] == 'title':
+				return(i[0])
 
 ############################################################################
 # Rajoute une ligne à la base de donnée, avec pour title le nom mis en param
@@ -219,7 +220,15 @@ class notion_connector:
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), 'error.json')
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on POST ' + url + self.DEFAULT)
-		return (json.loads(reply.text))
+		data_line = {
+			'page_id' : reply['id'],
+			'properties' : {}
+		}
+		for i in reply['properties'].items():
+			if i[1]['type'] == 'title':
+				data_line['title'] = self.getProperties(i[1])['value']
+			data_line['properties'][i[0]] = self.getProperties(i[1])
+		return(data_line)
 
 #############################################
 # Récupère la l'id de la ligne de la Database
